==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/kbibtexactiontextsearch.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qwidget.h>
#include <qlayout.h>
#include <qtoolbutton.h>
#include <qtimer.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qstring.h>
#include <ktoolbar.h>
#include <klocale.h>
#include <kdialog.h>
#include <kiconloader.h>

#include "kbibtexactiontextsearch.h"

KBibTeXActionTextSearch::KBibTeXActionTextSearch( const QString &text, const KShortcut &cut, KActionCollection *parent, const char *name )
        : KAction( text, cut, parent, name ), m_toolBar( NULL )
{
    m_inputTimer = new QTimer( this );

    connect( m_inputTimer, SIGNAL( timeout() ),
             SLOT( timeout() ) );
}


KBibTeXActionTextSearch::~KBibTeXActionTextSearch()
{
    delete m_inputTimer;
}

int KBibTeXActionTextSearch::plug( QWidget *parent, int index )
{
    m_toolBar = dynamic_cast<KToolBar *>( parent );

    m_widget = createWidget( parent );
    if ( !m_widget )
        return -1;

    // the check for null makes sure that there is only one toolbar that this is
    // "plugged" in to

    if ( !m_toolBar )
    {
        int id = KAction::getToolButtonID();

        m_toolBar->insertWidget( id, m_widget->width(), m_widget, index );

        addContainer( m_toolBar, id );
        connect( m_toolBar, SIGNAL( destroyed() ), this, SLOT( toolbarDestroyed() ) );
        connect( m_toolBar, SIGNAL( orientationChanged( Orientation ) ),
                 this, SLOT( updateOrientation() ) );
        connect( m_toolBar, SIGNAL( placeChanged( QDockWindow::Place ) ),
                 this, SLOT( updateOrientation() ) );

        updateOrientation();
        return ( containerCount() - 1 );
    }
    else
        updateOrientation();

    return -1;
}

void KBibTeXActionTextSearch::unplug( QWidget * /* parent */ )
{
    if ( m_toolBar != NULL )
    {
        int index = findContainer( m_toolBar );
        if ( index != -1 )
        {
            m_toolBar->removeItem( itemId( index ) );
            removeContainer( index );
        }
    }

    if ( m_widget != NULL )
        delete m_widget;
}

void KBibTeXActionTextSearch::clear()
{
    m_lineeditSearchText->clear();
}

void KBibTeXActionTextSearch::updateOrientation()
{}

QWidget *KBibTeXActionTextSearch::createWidget( QWidget *parent )
{
    if ( m_toolBar != NULL )
    {
        QWidget * base = new QWidget( parent );
        base->setBackgroundMode( Qt::PaletteButton );

        QHBoxLayout *layout = new QHBoxLayout( base, 2, KDialog::spacingHint() );

        QLabel *label = new QLabel( i18n( "Search:" ), base );
        label->setBackgroundMode( Qt::PaletteButton );
        layout->addWidget( label );

        m_lineeditSearchText = new QLineEdit( base, "search_lineedit" );
        layout->addWidget( m_lineeditSearchText );
        label->setBuddy( m_lineeditSearchText );

        connect( m_lineeditSearchText, SIGNAL( textChanged( const QString& ) ), SLOT( announceDoSearch() ) );
        connect( m_lineeditSearchText, SIGNAL( returnPressed() ), SLOT( announceDoSearch() ) );

        base->adjustSize();
        //         announceDoSearch();
        return base;
    }
    else
    {
        return NULL;
    }
}

void KBibTeXActionTextSearch::updateSize()
{}

void KBibTeXActionTextSearch::toolbarDestroyed()
{}

void KBibTeXActionTextSearch::announceDoSearch()
{
    if ( m_inputTimer->isActive() )
        m_inputTimer->stop();

    m_inputTimer->start( 0, true );
}

void KBibTeXActionTextSearch::timeout()
{
    emit doSearch( m_lineeditSearchText->text() );
}


#include "kbibtexactiontextsearch.moc"

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/kbibtexactiontextsearch.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qwidget.h>
#include <qlayout.h>
#include <qtoolbutton.h>
#include <qtimer.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qstring.h>
#include <ktoolbar.h>
#include <klocale.h>
#include <kdialog.h>
#include <kiconloader.h>

#include "kbibtexactiontextsearch.h"

KBibTeXActionTextSearch::KBibTeXActionTextSearch( const QString &text, const KShortcut &cut, KActionCollection *parent, const char *name )
        : KAction( text, cut, parent, name ), m_toolBar( NULL )
{
    m_inputTimer = new QTimer( this );

    connect( m_inputTimer, SIGNAL( timeout() ), SLOT( timeout() ) );
}


KBibTeXActionTextSearch::~KBibTeXActionTextSearch()
{
    delete m_inputTimer;
}

int KBibTeXActionTextSearch::plug( QWidget *parent, int index )
{
    m_toolBar = dynamic_cast<KToolBar *>( parent );

    m_widget = createWidget( parent );
    if ( !m_widget )
        return -1;

    // the check for null makes sure that there is only one toolbar that this is
    // "plugged" in to

    if ( !m_toolBar )
    {
        int id = KAction::getToolButtonID();

        m_toolBar->insertWidget( id, m_widget->width(), m_widget, index );

        addContainer( m_toolBar, id );
        connect( m_toolBar, SIGNAL( destroyed() ), this, SLOT( toolbarDestroyed() ) );
        connect( m_toolBar, SIGNAL( orientationChanged( Orientation ) ),
                 this, SLOT( updateOrientation() ) );
        connect( m_toolBar, SIGNAL( placeChanged( QDockWindow::Place ) ),
                 this, SLOT( updateOrientation() ) );

        updateOrientation();
        return ( containerCount() - 1 );
    }
    else
        updateOrientation();

    return -1;
}

void KBibTeXActionTextSearch::unplug( QWidget * /* parent */ )
{
    if ( m_toolBar != NULL )
    {
        int index = findContainer( m_toolBar );
        if ( index != -1 )
        {
            m_toolBar->removeItem( itemId( index ) );
            removeContainer( index );
        }
    }

    if ( m_widget != NULL )
        delete m_widget;
}

void KBibTeXActionTextSearch::clear()
{
    m_lineeditSearchText->clear();
}

void KBibTeXActionTextSearch::updateOrientation()
{}

QWidget *KBibTeXActionTextSearch::createWidget( QWidget *parent )
{
    if ( m_toolBar != NULL )
    {
        QWidget * base = new QWidget( parent );
        base->setBackgroundMode( Qt::PaletteButton );

        QHBoxLayout *layout = new QHBoxLayout( base, 2, KDialog::spacingHint() );

        QLabel *label = new QLabel( i18n( "Search:" ), base );
        label->setBackgroundMode( Qt::PaletteButton );
        layout->addWidget( label );

        m_lineeditSearchText = new QLineEdit( base, "search_lineedit" );
        layout->addWidget( m_lineeditSearchText );
        label->setBuddy( m_lineeditSearchText );

        connect( m_lineeditSearchText, SIGNAL( textChanged( const QString& ) ), SLOT( announceDoSearch() ) );
        connect( m_lineeditSearchText, SIGNAL( returnPressed() ), SLOT( announceDoSearch() ) );

        base->adjustSize();
        //         announceDoSearch();
        return base;
    }
    else
    {
        return NULL;
    }
}

void KBibTeXActionTextSearch::updateSize()
{}

void KBibTeXActionTextSearch::toolbarDestroyed()
{}

void KBibTeXActionTextSearch::announceDoSearch()
{
    if ( m_inputTimer->isActive() )
        m_inputTimer->stop();

    m_inputTimer->start( 0, true );
}

void KBibTeXActionTextSearch::timeout()
{
    emit doSearch( m_lineeditSearchText->text() );
}


#include "kbibtexactiontextsearch.moc"
